APIEntityRules class

Defines an EntityResolutionRules for a route.

Inheritance

Constructors

APIEntityRules(List<EntityRules<EntityRules>> rules, {bool globalRules = false, bool noGlobalRules = false})
const

Properties

entityAccessRules → List<EntityAccessRules>
no setter
entityResolutionRules → List<EntityResolutionRules>
no setter
globalRules → bool
If true apply this APIRouteRule declaration to all routes/methods. If false this instance will be applied only to routes/methods without any APIRouteRule declaration.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
noGlobalRules → bool
If true blocks APIRouteRule with globalRules to be applied to the route/method with this declaration.
finalinherited
rules → List<EntityRules<EntityRules>>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object>
override
toString() → String
A string representation of this object.
override
validate(APIRequest request) → bool
Returns true if the request is valid by this rule.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited