APIModuleInfo class

The APIModule information.

Returned by API-INFO.

Constructors

APIModuleInfo(APIModule module, [APIRequest? apiRequest])

Properties

apiRequest → APIRequest?
final
hashCode → int
The hash code for this object.
no setterinherited
module → APIModule
final
moduleClassReflection → ClassReflection?
final
name → String
Returns the name of the module.
no setter
routes → List<APIRouteInfo>
Returns the routes of the module.
no setter
rules → List<APIRouteRule>
Returns the module rules (through moduleClassReflection).
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
version → String?
Returns the version of the module.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited