APIModuleProxy class

A ClassProxy annotation for proxies on APIModule classes.

Inheritance
Annotations
  • @Target({TargetKind.classType})

Constructors

APIModuleProxy(String moduleClassName, {String libraryName = '', String libraryPath = '', Set<String> ignoreMethods = const <String>{}})
const

Properties

alwaysReturnFuture → bool
If true all methods will return a Future<R>.
finalinherited
className → String
The class name for the proxy.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
ignoreMethods → Set<String>
Methods to ignore.
finalinherited
ignoreMethods2 → Set<String>
Extra methods to ignore.
finalinherited
ignoreParametersTypes → Set<Type>
The parameters types to ignore
finalinherited
libraryName → String
The Dart library name with the className.
finalinherited
libraryPath → String
The library path for libraryName.
finalinherited
reflectionProxyName → String
The name of the generated reflection proxy.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
traverseReturnTypes → Set<Type>
The list return o types to traverse.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited