APIModuleProxyDirectCaller<T> class

An APIModuleProxy caller with direct calls to an api instance, for a specific module (moduleName).

Inheritance

Constructors

APIModuleProxyDirectCaller(APIRoot api, {required String moduleName, APICredential? credential, bool? responsesAsJson, APIModuleProxyResponseErrorHandler? errorHandler})

Properties

api → APIRoot
final
credential ↔ APICredential?
getter/setter pair
errorHandler → APIModuleProxyResponseErrorHandler?
The error handler to call when an HTTP response error happens.
final
hashCode → int
The hash code for this object.
no setterinherited
moduleName → String
final
responsesAsJson → bool
If true converts the response object to a JSON collection/data.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onCall(T instance, String methodName, Map<String, dynamic> parameters, TypeReflection? returnType) → FutureOr
Calls made through a ClassProxy will be intercepted by onCall implementation.
override
resolveResponse(TypeReflection? returnType, dynamic json) → Object?
inherited
responseToJson(dynamic payload, {APIResponse? apiResponse}) → dynamic
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

defaultErrorHandler ↔ APIModuleProxyResponseErrorHandler?
The default response error handler. See errorHandler.
getter/setter pair