APIPasswordNotHashed class

Password without hashing. This is marked as Deprecated to indicate to not use in production!

Inheritance
Annotations

Constructors

APIPasswordNotHashed()
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
Returns the name of this algorithm.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

ensureHashedPassword(String passwordOrHash) → String
Ensures that passwordOrHash is hashed with this algorithm.
inherited
hashPassword(String password) → String
Hashes password with this algorithm.
override
isHashedPassword(String passwordOrHash) → bool
Returns true if passwordOrHash is hashed with this algorithm.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited