APIPermission class

Constructors

APIPermission(String type, {bool enabled = true, DateTime? initTime, DateTime? endTime, Map<String, Object>? properties})
APIPermission.fromJson(Map json)
factory

Properties

enabled → bool
final
endTime → DateTime?
final
hashCode → int
The hash code for this object.
no setterinherited
initTime → DateTime?
final
properties → Map<String, Object>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
final

Methods

copy({bool? enabled, DateTime? initTime, DateTime? endTime, Map<String, Object>? properties}) → APIPermission
isEnabled({DateTime? now}) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

listFromJson(Object? json) → List<APIPermission>
normalizeType(String type) → String
validateType(String type) → bool