APIRouteRule class abstract

A route rule.

Implementers

Constructors

APIRouteRule({bool globalRules = false, bool noGlobalRules = false})
const

Properties

globalRules → bool
If true apply this APIRouteRule declaration to all routes/methods. If false this instance will be applied only to routes/methods without any APIRouteRule declaration.
final
hashCode → int
The hash code for this object.
no setterinherited
noGlobalRules → bool
If true blocks APIRouteRule with globalRules to be applied to the route/method with this declaration.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object>
toString() → String
A string representation of this object.
inherited
validate(APIRequest request) → bool
Returns true if the request is valid by this rule.

Operators

operator ==(Object other) → bool
The equality operator.
inherited