ClassProxy class

Informs that a class will be a proxy to a target class with className, without directly depending on the target class.

Implementers
Annotations
  • @Target({TargetKind.classType})

Constructors

ClassProxy(String className, {String libraryName = '', String libraryPath = '', String reflectionProxyName = '', Set<String> ignoreMethods = const <String>{}, Set<String> ignoreMethods2 = const <String>{}, bool alwaysReturnFuture = false, Set<Type> traverseReturnTypes = const <Type>{}, Set<Type> ignoreParametersTypes = const <Type>{}})
const

Properties

alwaysReturnFuture → bool
If true all methods will return a Future<R>.
final
className → String
The class name for the proxy.
final
hashCode → int
The hash code for this object.
no setterinherited
ignoreMethods → Set<String>
Methods to ignore.
final
ignoreMethods2 → Set<String>
Extra methods to ignore.
final
ignoreParametersTypes → Set<Type>
The parameters types to ignore
final
libraryName → String
The Dart library name with the className.
final
libraryPath → String
The library path for libraryName.
final
reflectionProxyName → String
The name of the generated reflection proxy.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
traverseReturnTypes → Set<Type>
The list return o types to traverse.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

returnFuture<T>(Object? ret) → Future<T>
returnFutureOr<T>(Object? ret) → FutureOr<T>
returnValue<T>(Object? ret) → T