DBAdapterCapability class

DBAdapter capabilities.

Implemented types
Implementers

Constructors

DBAdapterCapability({required DBDialect dialect, required bool transactions, required bool transactionAbort, required bool constraintSupport, required bool multiIsolateSupport, required DBAdapterCapabilityConnectivity connectivity})
const

Properties

connectivity → DBAdapterCapabilityConnectivity
The supported connection types.
final
constraintSupport → bool
true if the DB supports constraints.
final
dialect → DBDialect
The dialect of the DB.
final
fullTransaction → bool
true if the DB fully supports transactions and transactionAbort.
no setter
hashCode → int
The hash code for this object.
no setterinherited
info → String
no setter
multiIsolateSupport → bool
true if the DBAdapter supports execution in multiple Isolates.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
runtimeTypeNameSafe → String
Returns the runtimeType as String in safe way.
no setteroverride
transactionAbort → bool
true if the DB supports abortion of transactions.
final
transactions → bool
true if the DB supports transactions.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited