DBSQLAdapterCapability class

DBSQLAdapter capabilities.

Inheritance

Constructors

DBSQLAdapterCapability({required DBDialect dialect, required bool transactions, required bool transactionAbort, required bool constraintSupport, required bool tableSQL, required bool multiIsolateSupport, required DBAdapterCapabilityConnectivity connectivity})
const

Properties

connectivity → DBAdapterCapabilityConnectivity
The supported connection types.
finalinherited
constraintSupport → bool
true if the DB supports constraints.
finalinherited
dialect → DBDialect
The dialect of the DB.
finalinherited
fullTransaction → bool
true if the DB fully supports transactions and transactionAbort.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
info → String
no setteroverride
multiIsolateSupport → bool
true if the DBAdapter supports execution in multiple Isolates.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
runtimeTypeNameSafe → String
Returns the runtimeType as String in safe way.
no setteroverride
tableSQL → bool
true if the adapter supports table SQLs. See DBSQLAdapter.populateTables.
final
transactionAbort → bool
true if the DB supports abortion of transactions.
finalinherited
transactions → bool
true if the DB supports transactions.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited