EncodingValueNull<E> class

Inheritance

Constructors

EncodingValueNull(String key, Type? type, ValueEncoder<E, EncodingValueNull<E>> valueEncoder)

Properties

asList → List<EncodingValue<E, Object?>>
no setterinherited
encode → E
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
key → String
finalinherited
resolvedValue → Object?
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → Type?
finalinherited
valueEncoder → ValueEncoder<E, EncodingValueNull<E>>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited