EncodingValuePrimitive<E, T> class

Inheritance

Constructors

EncodingValuePrimitive(String key, Type? type, T resolvedValue, ValueEncoder<E, EncodingValuePrimitive<E, T>> valueEncoder)

Properties

asList → List<EncodingValue<E, Object?>>
no setterinherited
encode → E
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
key → String
finalinherited
resolvedValue → T
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → Type?
finalinherited
valueEncoder → ValueEncoder<E, EncodingValuePrimitive<E, T>>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited