EntityAccessRulesCached class

An EntityAccessRules with cache for some calls.

Implemented types

Constructors

EntityAccessRulesCached(EntityAccessRules accessRules)

Properties

accessRules → EntityAccessRules
final
cached → EntityAccessRules
no setteroverride
condition → EntityAccessRulesCondition?
no setteroverride
entityFields → List<String>?
no setteroverride
entityType → Type?
no setteroverride
hashCode → int
The hash code for this object.
no setteroverride
isInnocuous → bool
Returns true if this instance is equivalent to innocuous instance (no resolution rules to apply).
no setteroverride
isValid → bool
Return true if this instance rules are valid.
no setteroverride
masker → EntityAccessRulesMasker?
no setteroverride
rules → List<EntityAccessRules>?
no setteroverride
ruleType → EntityAccessRuleType?
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

applyMask<O extends Object, V>(O object, String field, V value, {EntityAccessRulesContext? context, Type? type}) → V
override
copyWith({EntityAccessRuleType? ruleType, Type? entityType, List<String>? entityFields, List<EntityAccessRules>? rules, EntityAccessRulesCondition? condition}) → EntityAccessRules
override
hasRuleForEntityType(Type type) → bool
override
hasRuleForEntityTypeField(Type type) → bool
override
hasRuleType(List<EntityAccessRuleType> ruleTypes) → bool
override
isAllowedEntityType(Type type) → bool?
override
isAllowedEntityTypeField(Type type, String field, {EntityAccessRulesContext? context}) → bool?
override
isMaskedEntityTypeField(Type type, String field, {EntityAccessRulesContext? context, bool direct = false}) → bool?
override
merge(EntityAccessRules? other) → EntityAccessRules
Merges this rules with other rules.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
simplified() → EntityAccessRules
override
toJson() → Map<String, Object?>
override
toJsonEncodable(APIRequest apiRequest, ToEncodableJsonProvider encodableJsonProvider, Object o) → ToEncodableJson?
override
toString() → String
A string representation of this object.
override
totalRules() → int
Returns the total number of applicable rules, including nested rules when present.
override
validate() → void
Validates this instances rules. See isValid.
override

Operators

operator ==(Object other) → bool
The equality operator.
override