isUnique property
bool
get
isUnique
Returns true if the annotated field should be unique.
Implementation
bool get isUnique => _unique;
Returns true if the annotated field should be unique.
bool get isUnique => _unique;