EntityPaginationSkipReason enum
Why a page was served without calling EntityPagination.pageLoader. See EntityPaginationPageSkipped.
Values
- alreadyLoaded → const EntityPaginationSkipReason
-
The page was already loaded, and was served from EntityPagination.
- inFlight → const EntityPaginationSkipReason
-
A fetch of the same page was already in-flight, and is shared with it.
- knownEmpty → const EntityPaginationSkipReason
-
The page is known to be past the end, so it can only be empty.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
EntityPaginationSkipReason> - A constant List of the values in this enum, in order of their declaration.