EntityRules<R extends EntityRules<R>> class abstract

Implementers

Constructors

EntityRules(bool? _innocuous)
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
isInnocuous → bool
Returns true if this instance is innocuous (no resolution rules to apply).
no setter
isValid → bool
Return true if this instance rules are valid.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

merge(R? other) → R
Merges this rules with other rules.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited
validate() → void
Validates this instances rules. See isValid.

Operators

operator ==(Object other) → bool
The equality operator.
inherited