HTMLInput class

An HTML input used by HTMLDocument.

Constructors

HTMLInput(String name, TypeInfo type, {Object? value})
HTMLInput.from(MapEntry<String, Object> entry)
factory

Properties

hashCode → int
The hash code for this object.
no setteroverride
name → String
The name of the input.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → TypeInfo
The type of the input.
final
value → Object?
The optional value of the input.
final

Methods

build() → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override