Initializable mixin

Mixin applications

Properties

hashCode → int
The hash code for this object.
no setterinherited
initializationStatus → InitializationStatus
Returns the current InitializationStatus.
no setter
isAsyncInitialization → bool
Returns true if this instance initialization was asynchronous.
no setter
isInitialized → bool
Returns true if this instance is already initialized.
no setter
isInitializing → bool
Returns true if this instance is in the middle of the initialization process.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkInitialized() → void
Checks if this instance is initialized.
doInitialization({Initializable? parent}) → FutureOr<InitializationResult>
Initialize this instance if is not initialized yet.
ensureInitialized({Initializable? parent}) → FutureOr<InitializationResult>
Ensures that this instance is initialized.
ensureInitializedAsync({Initializable? parent}) → FutureOr<InitializationResult>
Ensures that this instance is initialized. If is not initialized yet it will force an asynchronous initialization and return a Future.
executeInitialized<R>(ExecuteInitializedCallback<R> callback, {Initializable? parent}) → FutureOr<R>
Executes the callback ensuring that this instances was fully initialized.
initialize() → FutureOr<InitializationResult>
Initialization implementation. Do not call it directly, use doInitialization.
initializeDependencies() → FutureOr<List<Initializable>>
Return a List of Initializable instances that need to be initialized BEFORE initialize this instance.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

interfaceMethodsNames → const Set<String>