InstanceTracker<O extends Object, I extends Object> class
Tracks an instance with a info relationship.
Uses Expando.
Constructors
-
InstanceTracker(String name, InstanceInfoExtractor<
O, I> instanceInfoExtractor)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
instanceInfoExtractor
→ InstanceInfoExtractor<
O, I> -
The info extractor.
final
- name → String
-
Name of this instance tracker.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
extractInfo(
O o) → I -
Extract the info of instance
o. -
getTrackedInstanceInfo(
O o) → I? -
returns the
oinfo, if tracked. -
isTrackedInstance(
O o) → bool -
Returns
trueif instanceois tracked. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
trackInstance(
O o) → O -
Tracks instance
o -
trackInstanceNullable(
O? o) → O? -
Same as trackInstance with a nullable
o. -
trackInstances(
Iterable< O> os) → List<O> -
Tracks instances
os. -
trackInstancesNullable(
Iterable< O?> os) → List<O?> -
Same as trackInstanceNullable with a nullable
os. -
untrackInstance(
O? o) → void -
Untracks instance
o. -
untrackInstances(
Iterable< O?> os) → void -
Untrack instances
os.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited