IterableClassification class

Iterable elements classification. See EntityHandler.classifyIterableElements

Constructors

IterableClassification({bool hasNull = false, bool hasObj = false, bool hasMap = false, bool hasId = false, bool hasOther = false})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
hasId → bool
final
hasMap → bool
final
hasNull → bool
final
hasObj → bool
final
hasOther → bool
final
isAllID → bool
no setter
isAllMap → bool
no setter
isAllNull → bool
no setter
isAllNullOrEmpty → bool
no setter
isAllObj → bool
no setter
isEmpty → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited