JsonField class

Informs that a class field can be hidden JsonField.hidden or visible JsonField.visible

Inheritance
Annotations
  • @Target({TargetKind.field, TargetKind.getter})

Constructors

JsonField({bool hidden = false})
const
JsonField.hidden()
const
JsonField.visible()
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
isHidden → bool
Returns true if the annotated field should be hidden from JSON.
no setter
isVisible → bool
Returns true if the annotated field should be visible from JSON.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited