MethodReflectionExtension<O, R> extension

MethodReflection extension.

on

Properties

isAPIMethod bool

Available on MethodReflection<O, R>, provided by the MethodReflectionExtension extension

Returns true if this reflected method is an API method (returnsAPIResponse OR receivesAPIRequest).
no setter
isFullAPIMethod bool

Available on MethodReflection<O, R>, provided by the MethodReflectionExtension extension

Returns true if this reflected method is returnsAPIResponse AND receivesAPIRequest.
no setter
receivesAPIRequest bool

Available on MethodReflection<O, R>, provided by the MethodReflectionExtension extension

Returns true if this reflected method receives an APIRequest as parameter.
no setter
returnsAPIResponse bool

Available on MethodReflection<O, R>, provided by the MethodReflectionExtension extension

Returns true if this reflected method returns an APIResponse.
no setter