ParameterReflection class

A parameter reflection, used method arguments or class fields.

Constructors

ParameterReflection(TypeReflection type, String name, bool nullable, bool required, [Object? defaultValue, List<Object>? _annotations])
const

Properties

annotations → List<Object>?
The parameter annotations.
no setter
defaultValue → Object?
The default value of this parameter.
final
hasDefaultValue → bool
Returns true if defaultValue is NOT null.
no setter
hashCode → int
The hash code for this object.
no setteroverride
hasJsonNameAlias → bool
Returns true if this field/parameter has a JsonFieldAlias with a valid name.
no setter
jsonAnnotations → List<JsonAnnotation>
Returns the JsonAnnotation of this field/parameter.
no setter
jsonFieldAliasAnnotations → List<JsonFieldAlias>
Returns the JsonFieldAlias of this field/parameter.
no setter
jsonName → String
Returns the JsonFieldAlias alias name or the declared name of this field/parameter.
no setter
name → String
The name of the parameter.
final
nullable → bool
true if this parameter can be null.
final
required → bool
true if this parameter is required.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → TypeReflection
The Type of the parameter.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolveName(bool jsonName) → String
Resolves to name or to jsonName.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override