SQLDialect class

Inheritance

Constructors

SQLDialect(String name, {String elementQuote = '', bool acceptsOutputSyntax = false, bool acceptsReturningSyntax = false, bool acceptsTemporaryTableForReturning = false, bool returningAcceptsTableWildcard = true, bool acceptsInsertDefaultValues = false, bool acceptsInsertIgnore = false, bool acceptsInsertOnConflict = false, bool acceptsVarcharWithoutMaximumSize = false, bool foreignKeyCreatesImplicitIndex = true, bool createIndexIfNotExists = true, bool offsetRequiresLimit = false, String offsetMaxLimitValue = '18446744073709551615'})
const

Properties

acceptsInsertDefaultValues → bool
If true indicates that this adapter's SQL can use the DEFAULT VALUES directive for inserts.
final
acceptsInsertIgnore → bool
If true indicates that this adapter's SQL uses the IGNORE syntax for inserts.
final
acceptsInsertOnConflict → bool
If true indicates that this adapter's SQL uses the ON CONFLICT syntax for inserts.
final
acceptsOutputSyntax → bool
If true indicates that this adapter's SQL uses the OUTPUT syntax for inserts/deletes.
final
acceptsReturningSyntax → bool
If true indicates that this adapter's SQL uses the RETURNING syntax for inserts/deletes.
final
acceptsTemporaryTableForReturning → bool
If true indicates that this adapter's SQL needs a temporary table to return rows for inserts/deletes.
final
acceptsVarcharWithoutMaximumSize → bool
If true indicates that the VARCHAR can be defined without a maximum size.
final
createIndexIfNotExists → bool
Whether the SQL dialect supports IF NOT EXISTS on CREATE INDEX.
final
elementQuote → String
The type of "quote" to use to reference elements (tables and columns).
final
foreignKeyCreatesImplicitIndex → bool
If true, foreign keys implicitly create an index on the referencing columns.
final
hashCode → int
The hash code for this object.
no setteroverride
name → String
finalinherited
offsetMaxLimitValue → String
The maximum row count accepted by a LIMIT clause of this dialect, used as the LIMIT value when only an offset was requested and offsetRequiresLimit is true.
final
offsetRequiresLimit → bool
If true this dialect can't parse an OFFSET clause that is not preceded by a LIMIT clause (MySQL). See offsetMaxLimitValue.
final
returningAcceptsTableWildcard → bool
If true a RETURNING clause can select all the columns of a table qualified by its alias (RETURNING "alias".*).
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

limitOffsetSQL({int? limit, int? offset}) → String
Builds the LIMIT <limit> OFFSET <offset> clause of this dialect. Returns an empty String when neither limit nor offset applies.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
orderBySQL(String tableAlias, String column, {OrderDirection? direction}) → String
Builds the ORDER BY <tableAlias>.<column> ASC|DESC clause of this dialect.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override