TableSQL class abstract

A base class for CREATE and ALTER table SQLs.

Inheritance
Implementers

Constructors

TableSQL(SQLDialect dialect, String table, List<SQLEntry> entries, {String q = '"', String? parentTable})

Properties

allSQLBuilders → List<SQLBuilder>
All the SQLs of this builder tree node.
no setterinherited
dependentTables → List<String>?
Returns a list of dependent tables, usually referenced tables.
no setterinherited
dialect → SQLDialect
The SQL dialect.
finalinherited
entries → List<SQLEntry>
The fields and constraint entries.
final
extraSQLBuilders → List<SQLBuilder>?
Some extra SQL related to this SQL.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
mainTable → String
The main table of the SQL.
no setteroverride
parentTable → String?
The parent table;
final
q → String
The quote of the dialect.
finalinherited
referenceTables → List<String>
Returns a list of referenced tables.
no setteroverride
referenceTablesLength → int
Returns a number of referenced tables.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
table → String
The table name.
final

Methods

buildAllSQLs({bool multiline = true, bool ifNotExists = true}) → List<String>
Build all the SQLs, including the extraSQLBuilders.
inherited
buildSQL({bool multiline = true, bool ifNotExists = true}) → String
Build the SQL.
inherited
compareTo(SQLBuilder other) → int
Compares this object to another object.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited