TransactionAbortedError class

A Transaction abortion error.

Inheritance

Constructors

TransactionAbortedError({String? reason, Object? payload, Object? error, StackTrace? errorStackTrace})

Properties

error ↔ Object?
getter/setter pair
errorStackTrace ↔ StackTrace?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
payload ↔ Object?
getter/setter pair
reason ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stackTrace → StackTrace?
The stack trace at the point where this error was first thrown.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override
withErrorStackTrace(StackTrace? errorStackTrace) → TransactionAbortedError

Operators

operator ==(Object other) → bool
The equality operator.
inherited