TransactionOperationSubTransaction<O> class

Inheritance

Constructors

TransactionOperationSubTransaction(String repositoryName, Object executor, Transaction parentTransaction, Transaction subTransaction, {TransactionOperation? parentOperation})

Properties

canPropagate → bool
If true indicates that this operation can generated multiple operations, usually sub-entities requests/resolution.
finalinherited
command ↔ Object?
getter/setter pairinherited
duration → Duration?
no setterinherited
durationMsInfo → String
no setterinherited
endTime → DateTime?
no setterinherited
execution ↔ TransactionExecution?
getter/setter pairinherited
executor → Object
finalinherited
externalTransaction ↔ bool
latefinalinherited
hashCode → int
The hash code for this object.
no setterinherited
id ↔ int?
getter/setter pairinherited
initTime → DateTime
finalinherited
isExecuted → bool
no setterinherited
parentOperation ↔ TransactionOperation?
latefinalinherited
repositoryName → String
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subTransaction → Transaction
final
transaction ↔ Transaction
latefinalinherited
transactionId → int
no setterinherited
transactionRoot ↔ bool
latefinalinherited
type → TransactionOperationType
finalinherited

Methods

finish<R>(R result) → FutureOr<R>
inherited
isParentOperation(TransactionOperation? op) → bool
Returns true if op is a parent of this operation.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString({Set<Object>? processedObjects}) → String
A string representation of this object.
override
toStringSimple() → String
override
waitFinish({TransactionOperation? parentOperation, Duration timeout = const Duration(seconds: 40)}) → Future<bool>
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited