DBMySQLAdapterException class

Exception thrown by DBMySQLAdapter operations.

Inheritance
Available extensions

Constructors

DBMySQLAdapterException(String type, String message, {Object? parentError, StackTrace? parentStackTrace, Object? operation, Object? previousError})

Properties

hashCode → int
The hash code for this object.
no setterinherited
message → String
The exception message.
finalinherited
messageAndOperation → String

Available on DBException, provided by the DBExceptionExtension extension

message and operation.
no setter
operation → Object?
The operation that caused the Exception.
finalinherited
parentError → Object?
The parent error/exception. Usually the native Exception or Error of the database.
finalinherited
parentStackTrace → StackTrace?
finalinherited
previousError → Object?
The previous error in the same Transaction.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
runtimeTypeNameSafe → String
Returns the runtimeType as String in safe way.
no setteroverride
type → String
The type of the exception.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolveToString(Object? o, {String indent = '-- '}) → String?
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited