DBMySqlConnectionWrapper class abstract

A DBMySQLAdapter connection wrapper.

Inheritance

Constructors

DBMySqlConnectionWrapper(MySqlConnection nativeConnection)

Properties

connectionURL → String
no setterinherited
creationTime → DateTime
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
id → int
latefinalinherited
info → String
no setterinherited
isClosed → bool
no setterinherited
lastAccessTime → DateTime
no setterinherited
nativeConnection → MySqlConnection
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
runtimeTypeNameSafe → String
Returns the runtimeType as String in safe way.
no setterinherited

Methods

close() → void
inherited
closeImpl() → void
override
isClosedImpl() → bool
override
isInactive(Duration inactivityLimit, {DateTime? now}) → bool
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openTransaction(Future queryBlock(DBMySqlConnectionWrapper connectionTransaction)) → Future
query(String sql, [List<Object?>? values]) → Future<Results>
queryMulti(String sql, Iterable<List<Object?>> values) → Future<List<Results>>
timeSinceAccess({DateTime? now}) → Duration
inherited
toString() → String
A string representation of this object.
inherited
updateLastAccessTime({DateTime? now}) → void
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited