PostgreSQLConnectionTransactionWrapper class

A DBPostgreSQLAdapter connection transaction wrapper.

Inheritance

Constructors

PostgreSQLConnectionTransactionWrapper(PostgreSQLConnectionWrapper parent, Session nativeConnection, String? username, String host, int port, String database, bool secure)

Properties

connectionURL → String
no setterinherited
creationTime → DateTime
finalinherited
database → String
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
host → String
finalinherited
id → int
latefinalinherited
info → String
no setteroverride
isClosed → bool
no setterinherited
lastAccessTime → DateTime
no setterinherited
nativeConnection → Session
finalinherited
parent → PostgreSQLConnectionWrapper
final
port → int
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
runtimeTypeNameSafe → String
Returns the runtimeType as String in safe way.
no setteroverride
secure → bool
finalinherited
username → String?
finalinherited

Methods

cancelTransaction({String? reason}) → void
close() → void
inherited
closeImpl() → void
inherited
execute(String sql, {Map<String, dynamic>? substitutionValues}) → Future<int>
inherited
isClosedImpl() → bool
inherited
isInactive(Duration inactivityLimit, {DateTime? now}) → bool
inherited
mappedResultsQuery(String sql, {Map<String, dynamic>? substitutionValues}) → Future<List<Map<String, dynamic>>>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openTransaction(Future queryBlock(PostgreSQLConnectionTransactionWrapper connection), {int? commitTimeoutInSeconds}) → Future
override
query(String sql, {Map<String, dynamic>? substitutionValues}) → Future<Result>
inherited
timeSinceAccess({DateTime? now}) → Duration
inherited
toString() → String
A string representation of this object.
inherited
updateLastAccessTime({DateTime? now}) → void
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited