PostgreSQLConnectionWrapper class

A DBPostgreSQLAdapter connection wrapper.

Inheritance
Implementers

Constructors

PostgreSQLConnectionWrapper(Session nativeConnection, String? username, String host, int port, String database, bool secure)

Properties

connectionURL → String
no setteroverride
creationTime → DateTime
finalinherited
database → String
final
hashCode → int
The hash code for this object.
no setterinherited
host → String
final
id → int
latefinalinherited
info → String
no setterinherited
isClosed → bool
no setterinherited
lastAccessTime → DateTime
no setterinherited
nativeConnection → Session
finalinherited
port → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
runtimeTypeNameSafe → String
Returns the runtimeType as String in safe way.
no setteroverride
secure → bool
final
username → String?
final

Methods

close() → void
inherited
closeImpl() → void
override
execute(String sql, {Map<String, dynamic>? substitutionValues}) → Future<int>
isClosedImpl() → bool
override
isInactive(Duration inactivityLimit, {DateTime? now}) → bool
inherited
mappedResultsQuery(String sql, {Map<String, dynamic>? substitutionValues}) → Future<List<Map<String, dynamic>>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openTransaction(Future queryBlock(PostgreSQLConnectionTransactionWrapper connection), {int? commitTimeoutInSeconds}) → Future
query(String sql, {Map<String, dynamic>? substitutionValues}) → Future<Result>
timeSinceAccess({DateTime? now}) → Duration
inherited
toString() → String
A string representation of this object.
inherited
updateLastAccessTime({DateTime? now}) → void
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited