updatedRows property
int
get
updatedRows
The number of rows changed by the most recent statement.
Implementation
int get updatedRows;
The number of rows changed by the most recent statement.
int get updatedRows;