APIHotReload class abstract

Hot Reload handler.

Constructors

APIHotReload()

Properties

hashCode → int
The hash code for this object.
no setterinherited
isEnabled → bool
Returns true if Hot Reload is enabled.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

disable() → Future<bool>
Disables Hot Reload.
enable() → Future<bool>
Enables Hot Reload.
getIsolateID(Object isolate) → String?
Returns the isolate ID that can be used at ignoreIsolate.
ignoreIsolate(String isolateId, [bool ignore = true]) → void
Ignores an Isolate with isolateId for Hot Reload.
isHotReloadAllowed() → Future<bool>
Returns true if Hot Reload is allowed in this Dart process.
isIgnoredIsolate(String? isolateId) → bool
Returns true if isolateId is in ignore list for Hot Reload.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reload({bool force = false, bool autoEnable = true}) → Future<bool>
Triggers reload of modified source codes.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

get() → APIHotReload
Returns the static APIHotReload instance for the current platform.