sqlAdapter property

DBSQLiteAdapter? sqlAdapter
getter/setter pair

The adapter under test.

runSQL and listTables must reach the same database as the entity tests, and an in-memory database is only reachable through the adapter that owns its handle, so the test's adapter creator has to assign this.

Implementation

DBSQLiteAdapter? sqlAdapter;