APITestConfig class

An APIRoot test configuration.

Implementers

Constructors

APITestConfig(Map<String, dynamic> apiConfig)

Properties

apiConfigMap → Map<String, dynamic>
final
hashCode → int
The hash code for this object.
no setterinherited
isStarted → bool
Returns true if already started.
no setter
isStarting → bool
Returns true if starting.
no setter
isStopped → bool
Returns true if stopped.
no setter
isSupported → bool
Returns true if this test configuration is supported. See isUnsupported.
no setter
isUnsupported → bool
Alias to ![isSupported];
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unsupportedReason → String?
If isUnsupported is true should return a reason message. This can be used in tests to show the skip reason.
no setter

Methods

createAPIRootStarter<A extends APIRoot>(A apiRootInstantiator(APIConfig? apiConfig)) → APIRootStarter<A>
Creates an APIRootStarter using this APITestConfig as pre-initialization and stopper.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolveSupported() → FutureOr<bool>
Resolves if this configuration test is supported. See isSupported.
start() → FutureOr<bool>
The start operation.
stop() → FutureOr<bool>
The stop operation.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited