APITestConfigBase mixin

A base implementation of an APITestConfig. See startImpl and stopImpl.

Superclass constraints
Mixin applications

Properties

apiConfigMap → Map<String, dynamic>
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
isStarted → bool
Returns true if already started.
no setteroverride
isStarting → bool
Returns true if starting.
no setteroverride
isStopped → bool
Returns true if stopped.
no setteroverride
isSupported → bool
Returns true if this test configuration is supported. See isUnsupported.
no setteroverride
isUnsupported → bool
Alias to ![isSupported];
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unsupportedReason → String?
If isUnsupported is true should return a reason message. This can be used in tests to show the skip reason.
no setterinherited

Methods

createAPIRootStarter<A extends APIRoot>(A apiRootInstantiator(APIConfig? apiConfig)) → APIRootStarter<A>
Creates an APIRootStarter using this APITestConfig as pre-initialization and stopper.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolveSupported() → FutureOr<bool>
Resolves if this configuration test is supported. See isSupported.
override
resolveSupportedImpl() → FutureOr<bool>
The resolveSupported implementation.
start() → FutureOr<bool>
The start operation.
override
startImpl() → FutureOr<bool>
The start implementation.
stop() → FutureOr<bool>
The stop operation.
override
stopImpl() → FutureOr<bool>
The stop implementation.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited