APITestConfigDockerDB<C extends DockerContainer> class abstract

A base class for APITestConfig Docker database containers.

Inheritance
Implemented types
Mixed-in types
Implementers

Constructors

APITestConfigDockerDB(DockerHost dockerHost, String dbType, Map<String, dynamic> apiConfig, {String? containerNamePrefix, bool cleanContainer = true})

Properties

apiConfigMap → Map<String, dynamic>
finalinherited
cleanContainer → bool
If true will clean the container after stop. (docker run --rm)
final
container ↔ C?
The DockerContainer that was started.
getter/setter pairinherited
containerNamePrefix → String
The container name prefix.
final
dbConfig → Map<String, dynamic>
The database configuration Map.
no setterinherited
dbName → String
The dbConfig database name.
no setterinherited
dbPass → String
The dbConfig password.
no setterinherited
dbPort → FutureOr<int>
The dbConfig port (database exposed port for connections).
no setterinherited
dbType → String
The DB type/name.
final
dbUser → String
The dbConfig username.
no setterinherited
dockerHost ↔ DockerHost
The DockerHost for DockerCommander.
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
isStarted → bool
Returns true if already started.
no setterinherited
isStarting → bool
Returns true if starting.
no setterinherited
isStopped → bool
Returns true if stopped.
no setterinherited
isSupported → bool
Returns true if this test configuration is supported. See isUnsupported.
no setterinherited
isUnsupported → bool
Alias to ![isSupported];
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
runtimeTypeNameSafe → String
Returns the runtimeType as String in safe way.
no setterinherited
stderr → Output?
The STDERR Output of the container.
no setterinherited
stderrAsString → String
The stderr as String.
no setterinherited
stdout → Output?
The STDOUT Output of the container.
no setterinherited
stdoutAsString → String
The stdout as String.
no setterinherited
stopContainerTimeout → Duration
The timeout to stop the container.
no setterinherited
unsupportedReason → String?
If isUnsupported is true should return a reason message. This can be used in tests to show the skip reason.
no setterinherited

Methods

createAPIRootStarter<A extends APIRoot>(A apiRootInstantiator(APIConfig? apiConfig)) → APIRootStarter<A>
Creates an APIRootStarter using this APITestConfig as pre-initialization and stopper.
inherited
createContainer(DockerCommander dockerCommander) → Future<C>
DockerContainer creation implementation.
override
createDBContainerConfig(int dbPort) → DockerContainerConfig<C>
The DockerContainerConfig instantiator.
listTables() → FutureOr<List<String>>
List the database tables names.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolveDbPort(int port) → FutureOr<int>
Resolves the database port.
inherited
resolveFreePort(int port) → FutureOr<int>
Resolves a free-port to use for the database.
inherited
resolveSupported() → FutureOr<bool>
Resolves if this configuration test is supported. See isSupported.
inherited
resolveSupportedImpl() → FutureOr<bool>
The resolveSupported implementation.
inherited
start() → FutureOr<bool>
The start operation.
inherited
startImpl() → Future<bool>
The start implementation.
inherited
stop() → FutureOr<bool>
The stop operation.
inherited
stopContainer() → FutureOr<bool>
Stops the container. Called by stopImpl.
inherited
stopImpl() → FutureOr<bool>
The stop implementation.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited