SQLDialect class
Constructors
- SQLDialect(String name, {String elementQuote = '', bool acceptsOutputSyntax = false, bool acceptsReturningSyntax = false, bool acceptsTemporaryTableForReturning = false, bool returningAcceptsTableWildcard = true, bool acceptsInsertDefaultValues = false, bool acceptsInsertIgnore = false, bool acceptsInsertOnConflict = false, bool acceptsVarcharWithoutMaximumSize = false, bool foreignKeyCreatesImplicitIndex = true, bool createIndexIfNotExists = true, bool offsetRequiresLimit = false, String offsetMaxLimitValue = '18446744073709551615'})
-
const
Properties
- acceptsInsertDefaultValues → bool
-
If
trueindicates that this adapter's SQL can use theDEFAULT VALUESdirective for inserts.final - acceptsInsertIgnore → bool
-
If
trueindicates that this adapter's SQL uses theIGNOREsyntax for inserts.final - acceptsInsertOnConflict → bool
-
If
trueindicates that this adapter's SQL uses theON CONFLICTsyntax for inserts.final - acceptsOutputSyntax → bool
-
If
trueindicates that this adapter's SQL uses theOUTPUTsyntax for inserts/deletes.final - acceptsReturningSyntax → bool
-
If
trueindicates that this adapter's SQL uses theRETURNINGsyntax for inserts/deletes.final - acceptsTemporaryTableForReturning → bool
-
If
trueindicates that this adapter's SQL needs a temporary table to return rows for inserts/deletes.final - acceptsVarcharWithoutMaximumSize → bool
-
If
trueindicates that theVARCHARcan be defined without a maximum size.final - createIndexIfNotExists → bool
-
Whether the SQL dialect supports
IF NOT EXISTSonCREATE INDEX.final - elementQuote → String
-
The type of "quote" to use to reference elements (tables and columns).
final
- foreignKeyCreatesImplicitIndex → bool
-
If
true, foreign keys implicitly create an index on the referencing columns.final - hashCode → int
-
The hash code for this object.
no setteroverride
- name → String
-
finalinherited
- offsetMaxLimitValue → String
-
The maximum row count accepted by a
LIMITclause of this dialect, used as theLIMITvalue when only anoffsetwas requested and offsetRequiresLimit istrue.final - offsetRequiresLimit → bool
-
If
truethis dialect can't parse anOFFSETclause that is not preceded by aLIMITclause (MySQL). See offsetMaxLimitValue.final - returningAcceptsTableWildcard → bool
-
If
trueaRETURNINGclause can select all the columns of a table qualified by its alias (RETURNING "alias".*).final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
limitOffsetSQL(
{int? limit, int? offset}) → String -
Builds the
LIMIT <limit> OFFSET <offset>clause of this dialect. Returns an emptyStringwhen neitherlimitnoroffsetapplies. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
orderBySQL(
String tableAlias, String column, {OrderDirection? direction}) → String -
Builds the
ORDER BY <tableAlias>.<column> ASC|DESCclause of this dialect. -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override