DBSQLiteConnectionWrapper class abstract

A DBSQLiteAdapter connection wrapper.

Inheritance

Constructors

DBSQLiteConnectionWrapper(Database nativeConnection)

Properties

connectionURL String
no setterinherited
creationTime DateTime
finalinherited
hashCode int
The hash code for this object.
no setterinherited
id int
latefinalinherited
info String
no setterinherited
isClosed bool
no setterinherited
lastAccessTime DateTime
no setterinherited
lastInsertRowId int
The rowid of the most recent successful insert.
no setter
nativeConnection → Database
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
runtimeTypeNameSafe String
Returns the runtimeType as String in safe way.
no setterinherited
updatedRows int
The number of rows changed by the most recent statement.
no setter

Methods

close() → void
inherited
closeImpl() → void
Only marks this wrapper closed: the native Database is shared by every wrapper and is owned (and disposed) by DBSQLiteAdapter.
override
execute(String sql, [List<Object?>? parameters]) → void
Runs sql discarding any rows.
isClosedImpl() bool
override
isInactive(Duration inactivityLimit, {DateTime? now}) bool
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openTransaction(Future queryBlock(DBSQLiteConnectionWrapper connectionTransaction)) Future
Runs queryBlock inside a SQL transaction.
select(String sql, [List<Object?>? parameters]) → ResultSet
Runs sql and returns its rows.
timeSinceAccess({DateTime? now}) Duration
inherited
toString() String
A string representation of this object.
inherited
updateLastAccessTime({DateTime? now}) → void
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited