dockerChosenPort property
If true, Docker chooses a free host port for the database when the
container starts, and it is written to the port of dbConfig.
Free of races between tests running in parallel, unlike a port
resolved before starting the container (see dbPort).
Implementation
final bool dockerChosenPort;